package com.emato.ccnet.biz.req.order.csp;

import com.emato.ccnet.biz.req.CebRespOneDateRespons;
import com.emato.ccnet.contants.Contants;
import com.emato.ccnet.dto.OrderResponse;
import com.emato.ccnet.domain.ccnet.CusOrderStatus;
import com.emato.ccnet.message.Result;
import com.emato.ccnet.msg.ResponseMessage;
import com.emato.ccnet.service.ccent.CusOrderRespService;
import com.emato.ccnet.service.ccent.CusOrderStatusService;
import com.emato.ccnet.util.JacksonUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.google.common.collect.ImmutableMap;
import com.google.gson.Gson;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class Ceb311SendDateResponse implements CebRespOneDateRespons {
    private static final Logger LOGGER = LoggerFactory.getLogger(Ceb311SendDateResponse.class);
    @Autowired
    private CusOrderRespService cusOrderRespService;

    @Autowired
    private CusOrderStatusService cusOrderStatusService;
    /**
     * 响应数据处理
     * @param response
     * @param orderSn
     * @return
     */
    @Override
    public ResponseMessage addResponse(String response, String orderSn) {

        //解析响应数据
        OrderResponse orderResponse = analysisResponse(response);
        if(orderResponse == null){
            String info = "解析响应数据失败";
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }

        //查找电子订单状态表
        Map<String, Object> reqParam = ImmutableMap.of("orderSn", orderSn,"sendStatus",Contants.DECLARATION_STATUS);
        CusOrderStatus cusOrderStatus = cusOrderStatusService.findCusOrderStatus(reqParam);
        if(cusOrderStatus == null){
            String info = "查找电子订单状态表数据失败";
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);

        }

        //对回执状态进行处理
        if(Contants.CSP_RESPONSE_SUCCESS.equals(orderResponse.getCode())){
            cusOrderStatus.setModerSn(Contants.CREATER_NUMBER);
            cusOrderStatus.setModTime(new Date());

            cusOrderStatusService.updateCusOrderStatus(cusOrderStatus);

            return ResponseMessage.success();
        }else{
            cusOrderStatus.setModerSn(Contants.CREATER_NUMBER);
            cusOrderStatus.setModTime(new Date());
            cusOrderStatus.setNote(orderResponse.getMsg());
            cusOrderStatusService.updateCusOrderStatus(cusOrderStatus);
            String info = orderResponse.getMsg();
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }

    }

    /**
     * 解析响应数据
     * @param response
     * @return
     */
    private static OrderResponse analysisResponse(String response) {
        Gson gson = new Gson();
        Result result = gson.fromJson(response, Result.class);
        if(result == null){
            LOGGER.info("解析响应数据Result失败");
            return null;
        }
        Object dataResult = result.getData();
        String data = (String)dataResult;
        List<OrderResponse> orderResponseList  = gson.fromJson(data, List.class);
//        List<OrderResponse> orderResponseList  = JacksonUtil.fromListJson(JacksonUtil.toJson(data), new TypeReference<List<OrderResponse>>() {});

        if(orderResponseList == null){
            LOGGER.info("解析响应数据OrderResponse集合失败");
            return null;
        }

        OrderResponse orderResponse = gson.fromJson(gson.toJson(orderResponseList.get(0)), OrderResponse.class);

        return orderResponse;

    }

}
