package com.emato.ccnet.biz.req.pay.alipay;

import com.emato.ccnet.biz.req.CebRespTwoDateRespons;
import com.emato.ccnet.contants.Contants;
import com.emato.ccnet.domain.ccnet.CusAlipay;
import com.emato.ccnet.domain.ccnet.CusAlipayResp;
import com.emato.ccnet.domain.ccnet.CusAlipayStatus;
import com.emato.ccnet.service.ccent.CusAlipayRespService;
import com.emato.ccnet.service.ccent.CusAlipayStatusService;
import com.emato.ccnet.util.XmlUtil;
import com.google.common.collect.ImmutableMap;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.Map;

@Component
@Transactional(value = "secondTransactionManager")
public class Ceb411SendDateResponse implements CebRespTwoDateRespons {
    private static final Logger LOGGER = LoggerFactory.getLogger(Ceb411SendDateResponse.class);
    @Autowired
    private CusAlipayRespService cusAlipayRespService;

    @Autowired
    private CusAlipayStatusService cusAlipayStatusService;
    /**
     * 增加相应的数据，以及修改请求的状态
     * @param response
     * @return
     */
    @Override
    public int addResponse(String response,CusAlipay cusAlipay) {
        //将xml解析成map形式
        Map<String,String> map = XmlUtil.xmlToMap(response);
        if(map == null){
            LOGGER.info("将xml解析成map形式失败");
            return 0;
        }

        //增加海关支付单阿里回执记录并返回响应表中的数据
        CusAlipayResp addcusAlipayResp = cusAlipayRespService.addCusAlipayResp(map,cusAlipay);
        if(addcusAlipayResp == null){
            LOGGER.info("增加海关支付单阿里回执记录并返回响应表中的数据失败");
            return 0;
        }

        //通过编号查找支付单阿里状态表
        Map<String, Object> cusAlipayMap = ImmutableMap.of("cusPaySn", cusAlipay.getCusPaySn(), "sendStatus", Contants.SENDING_STATUS);
        CusAlipayStatus cusAlipayStatus = cusAlipayStatusService.findCusAlipayStatus(cusAlipayMap);
        if(cusAlipayStatus == null){
            LOGGER.info("通过编号查找支付单阿里状态表的数据失败");
            return 0;
        }

        //判断回调的状态
        int judgeAlipayStatus = judgeAlipayStatus(map);
        if(judgeAlipayStatus != 1){
            addcusAlipayResp.setSendStatus(Contants.FAIL_STATUS);
            cusAlipayStatus.setAlipayRespStatus(Contants.FAIL_STATUS);
            cusAlipayStatus.setAlipayDeclareNo(map.get("alipay_declare_no"));
            cusAlipayStatus.setTradeNo(map.get("trade_no"));
            cusAlipayStatus.setIdentityCheck(map.get("identity_check"));
            //更新支付单状态
            int updateCusAlipayFailResp = cusAlipayRespService.updateCusAlipayResp(addcusAlipayResp);
            if(updateCusAlipayFailResp <= 0){
                LOGGER.info("更新支付单状态表的数据失败updateCusAlipayFailResp="+updateCusAlipayFailResp);
                return 0;
            }

            //更新支付单阿里状态
            int updateCusAlipayFailStatus = cusAlipayStatusService.updateCusAlipayStatus(cusAlipayStatus);
            if(updateCusAlipayFailStatus <= 0){
                LOGGER.info("更新支付单阿里状态表的数据失败updateCusAlipayFailStatus="+updateCusAlipayFailStatus);
                return 0;
            }

            LOGGER.info("回调请求失败或者接入数据失败");
            return 0;
        }else {
            addcusAlipayResp.setSendStatus(Contants.SUCCESS_STATUS);
            //更新支付单状态
            int updateCusAlipaySuccessResp = cusAlipayRespService.updateCusAlipayResp(addcusAlipayResp);
            if(updateCusAlipaySuccessResp <= 0){
                LOGGER.info("更新支付单阿里状态表的数据失败updateCusAlipaySuccessResp="+updateCusAlipaySuccessResp);
            }

            return 1;
        }
    }

    /**
     * 判断回调的状态
     * @param map
     * @return
     */
    private int judgeAlipayStatus(Map<String, String> map) {

        if(map.get("is_success") != null && Contants.SUCCESS.equals(map.get("is_success"))){
            if(map.get("result_code") != null && Contants.SUCCESS_CODE.equals(map.get("result_code"))){
                return 1;
            }else {
                return 0;
            }
        }else {
            return 0;
        }
    }

}
