package com.emato.ccnet.biz.req.pay.icbc;

import com.emato.ccnet.biz.req.CusReqBiz;
import com.emato.ccnet.config.Cus;
import com.emato.ccnet.cus.message.req.CebReqRoot;
import com.emato.ccnet.cus.message.support.CebSupport;
import com.emato.ccnet.domain.kmall.PayBill;
import com.emato.ccnet.msg.ResponseMessage;
import com.google.common.base.Joiner;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMap;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * 海关支付单 业务
 * @author Scott Chen
 * @version 1.0
 * 2017-11-07 10:10
 */
@Component
public class Ceb411PayBillBiz implements CusReqBiz {
    private static final Logger LOGGER = LoggerFactory.getLogger(Ceb411PayBillBiz.class);

    @Autowired
    private Cus cus;

    @Autowired
    private Ceb411PayBillData ceb411PayBillData;
    @Autowired
    private CebReq411PayBillMessage ceb411PayBillMessage;
    @Autowired
    private Ceb411PayBillTransfer ceb411PayBillTransfer;
    @Autowired
    private Ceb411PayBillSend ceb411PayBillSend;
    @Autowired
    private Ceb411PayBillSendAfter ceb411PayBillSendAfter;

    private Map<String, Object> param = Collections.EMPTY_MAP;


    /**
     * 业务入口
     * @param param
     * @return
     */
    @Override
    public ResponseMessage biz(Map<String, Object> param) {
        if (param.isEmpty()) {
            String info = "【CEB411】请求订单支付数据,入参为空";
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }

        //查询支付单数据
        List list = ceb411PayBillData.getData(param);
        if (list.isEmpty()) {
            String info = "【CEB411】没有订单数据, 生成海关支付单报文提前结束";
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }

        //订单发送海关处理
        List result = sendCusHandle(list);

        return ResponseMessage.success(result);
    }


    private List sendCusHandle(List list) {

        //记录发送成功,发送失败订单
        List<String> sucList = new ArrayList<>();
        List<String> failedList = new ArrayList<>();

        //支付单数据
        List<PayBill> payBillList = (List<PayBill>) list;
        for (PayBill payBill : payBillList) {
            try {
                //生成请求报文文件名
                String msgFileName = CebSupport.buildFileName(
                        CebSupport.CEB411,
                        cus.getAlipay().get("senderID"),
                        CebSupport.RECEIVER_ID);
                LOGGER.info("--- 订单:【{}】, 支付单:【{}】, 生成EPort请求报文件名:{}", payBill.getOrderNo(), payBill.getTradeNo(), msgFileName);

                //生成请求报文
                LOGGER.info("--- 订单:【{}】, 支付单:【{}】,报文对象生成开始......", payBill.getOrderNo(), payBill.getTradeNo());
                CebReqRoot cebReqRoot;

                try {
                    ImmutableMap.Builder<String, Object> builder = new ImmutableMap.Builder<>();
                    builder.put("payBill", payBill);
                    builder.put("msgFileName", msgFileName);

                    //生成报文
                    cebReqRoot = ceb411PayBillMessage.buildMessage(builder.build(), CebSupport.CEB411, payBill.getOrderNo());

                } catch (Exception e) {
                    String str = "--- 订单:【" + payBill.getOrderNo() + "】, 支付单:【" + payBill.getTradeNo() + "】, 生成请求报文失败";
                    LOGGER.error(str, e);
                    //失败记录
                    failedList.add(payBill.getOrderNo());
                    //其它继续生成
                    continue;
                }

                if (cebReqRoot == null) {
                    String str = "--- 订单:【" + payBill.getOrderNo() + "】, 支付单:【" + payBill.getTradeNo() + "】, 生成请求报文为空";
                    LOGGER.error(str);
                    //失败记录
                    failedList.add(payBill.getOrderNo());
                    //其它继续生成
                    continue;
                }

                LOGGER.info("--- 订单:【{}】, 支付单:【{}】,生成请求报文成功", payBill.getOrderNo(), payBill.getTradeNo());

                //报文对象转XML字符串
                String msgXml =  ceb411PayBillTransfer.transform(cebReqRoot, payBill.getOrderNo());
                if (StringUtils.isBlank(msgXml)) {
                    String str = "--- 订单:【" + payBill.getOrderNo() + "】, 支付单:【" + payBill.getTradeNo() + "】, 报文对象转XML字符串为空";
                    LOGGER.error(str);
                    //失败记录
                    failedList.add(payBill.getOrderNo());
                    //其它继续生成
                    continue;
                }
                LOGGER.info("--- 订单:【{}】, 支付单:【{}】,报文对象转XML字符串成功", payBill.getOrderNo(), payBill.getTradeNo());

                //报文xml字符串输出存放指定到目录
                boolean bl = ceb411PayBillSend.send(msgXml, CebSupport.CEB411, msgFileName, payBill.getOrderNo());
                if (!bl) {
                    String str = "--- 订单:【" + payBill.getOrderNo() + "】, 支付单:【" + payBill.getTradeNo() + "】, XML字符串保存为文件失败";
                    LOGGER.error(str);
                    //失败记录
                    failedList.add(payBill.getOrderNo());
                    //其它继续生成
                    continue;
                }
                LOGGER.info("--- 订单:【{}】, 支付单:【{}】,XML字符串保存为文件成功", payBill.getOrderNo(), payBill.getTradeNo());

                //记录成功
                sucList.add(payBill.getOrderNo());

            } catch (final RuntimeException e) {
                String str = "--- 订单:【" + payBill.getOrderNo() + "】, 支付单:【" + payBill.getTradeNo() + "】, 生成请求报文异常";
                LOGGER.error(str);
                //失败记录
                failedList.add(payBill.getOrderNo());
                //其它继续生成
                continue;
            }
        }

        LOGGER.info("--- 【CEB411】【成功】订单数:{}, 订单: {}", sucList.size(), Joiner.on(",").skipNulls().join(sucList.toArray()));
        LOGGER.info("--- 【CEB411】【失败】订单数:{}, 订单: {}", failedList.size(), Joiner.on(",").skipNulls().join(failedList.toArray()));

        ceb411PayBillSendAfter.afterSend(sucList, failedList);

        Map<String, Object> sucMap = ImmutableMap.of("suc", sucList);
        Map<String, Object> failedMap = ImmutableMap.of("failed", failedList);
        List result = ImmutableList.of(sucMap, failedMap);
        return result;
    }

    public Map<String, Object> getParam() {
        return param;
    }

    public void setParam(Map<String, Object> param) {
        this.param = param;
    }
}
