package com.emato.ccnet.biz.req.waybill.oms;

import com.emato.ccnet.biz.req.CebReqBiz;
import com.emato.ccnet.msg.ResponseMessage;
import com.google.common.collect.ImmutableMap;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 海关电子订单, 海关运单 业务
 * @author Scott Chen
 * @version 1.0
 * 2017-11-07 09:57
 */
@Component
public class Ceb511OmsWayBiz implements CebReqBiz {
    private static final Logger LOGGER = LoggerFactory.getLogger(Ceb511OmsWayBiz.class);

    @Autowired
    private Ceb511OmsWayGetDate ceb511OmsWayGetDate;

    @Autowired
    private Ceb511OmsWayAddDate ceb511OmsWayAddDate;

    @Autowired
    private Ceb511SendDateRequest ceb511SendDateRequest;

    @Value("${db.ceb511-send-oms.data-size}")
    private String limit = "20";

    /**
     * 业务入口
     * @return
     */
    @Override
    public ResponseMessage biz() {

        /*if (param.isEmpty()) {
            String info = "【CEB311CDB511】请求订单数据,入参为空";
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }*/
        Map<String,Object> reqParam = ImmutableMap.of("number", limit);
        //查询海关运单数据
        List list = ceb511OmsWayGetDate.getData(reqParam);
        if (list.isEmpty()) {
            String info = "【CEB311CDB511】没有订单数据, 提前结束";
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }

        //添加海关运单数据
        ResponseMessage responseMessage = ceb511OmsWayAddDate.addDate(list);
        if(!ResponseMessage.isSuccess(responseMessage)){
            String info = "生成海关运单初始化失败" + responseMessage.getMsg();
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }

        //发送数据请求并响应
        ResponseMessage ceb511ResponseMessage = ceb511SendDateRequest.sendDate();
        if(!ResponseMessage.isSuccess(ceb511ResponseMessage)){
            String info = "发送请求响应失败" + ceb511ResponseMessage.getMsg();
            LOGGER.error("--- {}", info);
            return ResponseMessage.failed(info);
        }

        return ResponseMessage.success();
    }

}
