package com.emato.ccnet.biz.req.waybill.oms;

import com.emato.ccnet.biz.req.CebReqSendDateAfter;
import com.emato.ccnet.contants.Contants;
import com.emato.ccnet.service.ccent.CusWaybillStatusService;
import com.emato.ccnet.service.kmall.KmallOrderService;
import com.google.common.collect.ImmutableMap;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 海关电子订单 运单 报文发送后
 * @author Scott Chen
 * @version 1.0
 * 2017-11-08 14:14
 */
@Component
public class Ceb511SendDateAfter implements CebReqSendDateAfter {
    private static final Logger LOGGER = LoggerFactory.getLogger(Ceb511SendDateAfter.class);

    @Autowired
    private KmallOrderService kmallOrderService;

    @Autowired
    private CusWaybillStatusService cusWaybillStatusService;

    /**
     * 更新状态
     * @param sucList
     * @param failedList
     * @return
     */
    @Override
    public boolean afterSend(List<String> sucList, List<String> failedList) {
        List<Map<String, Object>> sucs = new ArrayList<>();
        List<Map<String, Object>> faileds = new ArrayList<>();
        List<Map<String, Object>> kmallcucs = new ArrayList<>();
        List<Map<String, Object>> kmallFaileds = new ArrayList<>();

        //全部处理完后
        if (sucList.size() > 0) {
            LOGGER.info("--- 【CEB311CDB511】更新【成功】报文订单记录......");
            sucList.stream().forEach(x->{
                Map<String, Object> kmallmap = ImmutableMap.of("orderNo", x, "cusWaybillFlag", Contants.SUCCESS_STATUS);
                Map<String, Object> map = ImmutableMap.of("merchOrderSn", x, "sendStatus", Contants.SUCCESS_STATUS);
                kmallcucs.add(kmallmap);
                sucs.add(map);
            });
            int i = kmallOrderService.updateCusKmallOrderStatusBatch(kmallcucs);
            cusWaybillStatusService.updateCusWaybillStatusBatch(sucs);

        }

        if (failedList.size() > 0) {
            LOGGER.info("--- 【CEB311CDB511】更新【失败】报文订单记录......");
            failedList.stream().forEach(x->{
                Map<String, Object> kmallmap = ImmutableMap.of("orderNo", x,  "cusWaybillFlag", Contants.FAIL_STATUS);
                Map<String, Object> map = ImmutableMap.of("merchOrderSn", x, "sendStatus", Contants.FAIL_STATUS);
                kmallFaileds.add(kmallmap);
                faileds.add(map);
            });
            int i = kmallOrderService.updateCusKmallOrderStatusBatch(kmallFaileds);
            cusWaybillStatusService.updateCusWaybillStatusBatch(faileds);
        }

        return true;
    }
}
