package com.emato.ccnet.config;

import com.emato.ccnet.util.JacksonUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.boot.autoconfigure.web.HttpMessageConverters;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.converter.StringHttpMessageConverter;
import org.springframework.http.converter.json.MappingJackson2HttpMessageConverter;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;

import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

/**
 * HTTP 请求响应消息转换
 * @author Scott Chen
 * @since 1.0
 * 2018-02-03
 */
@Configuration
public class HttpMsgConverter {

    /**
     * 扩展现有的消息转换器链表
     * 也可以继承并重写{@link WebMvcConfigurerAdapter#configureMessageConverters}方法
     * @return
     */
    @Bean
    public HttpMessageConverters httpMessageConverters() {
        List<HttpMessageConverter<?>> list = new ArrayList<>();
        list.add(httpMessageConverter());
        list.add(mappingJackson2HttpMessageConverter());
        return new HttpMessageConverters(list);
    }

    /**
     * jackson进行消息转换时,处理中文乱码
     * @return
     */
    @Bean
    public HttpMessageConverter httpMessageConverter() {
        StringHttpMessageConverter messageConverter = new StringHttpMessageConverter();
        messageConverter.setSupportedMediaTypes(mediaTypes());
        messageConverter.setDefaultCharset(Charset.forName("UTF-8"));
        return messageConverter;
    }

    /**
     * 处理中文乱码
     * @return
     */
    public List<MediaType> mediaTypes() {
        //处理中文乱码
        List<MediaType> list = new LinkedList();
        list.add(MediaType.TEXT_HTML);
        list.add(MediaType.APPLICATION_JSON_UTF8);
        return list;
    }


    /**
     * HTTP 请求消息转换器
     * 处理Date日期类型,处理LocalDateTime日期类型
     * 使用<code>MappingJackson2HttpMessageConverter</code>类
     * @return
     */
    @Bean
    public MappingJackson2HttpMessageConverter mappingJackson2HttpMessageConverter() {
        MappingJackson2HttpMessageConverter messageConverter = new MappingJackson2HttpMessageConverter();
        messageConverter.setObjectMapper(objectMapper());
        messageConverter.setSupportedMediaTypes(mediaTypes());
        return messageConverter;
    }

    /**
     * HTTP 响应消息处理
     * <code>ResponseBody</code>格式化响应消息中的<code>LocalDateTime</code>日期类型
     * <code>{@link JacksonUtil#getObjectMapper}</code>使用<code>JavaTimeModule</code>格式化响应消息中的<code>LocalDateTime</code>日期类型
     * @return
     */
    @Bean
    public ObjectMapper objectMapper() {
        ObjectMapper objectMapper = JacksonUtil.getObjectMapper();
        return objectMapper;
    }


}
