package com.emato.ccnet.cus.message.req;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;

/**
 * EPort请求报文头
 * 所有请求消息头相同,其它请求消息根节点的子节点
 * Java报文对象转XML
 *
 * @author Scott Chen
 * @date 2017/11/05
 */
@XmlAccessorType(XmlAccessType.FIELD)
public class CebReqMessageHead implements Serializable {

    private static final long serialVersionUID = -9018799772407388539L;

    /**
     * 报文唯一编号
     * 企业系统生成36位报文唯一序号（要求为guid36位，英文字母大写）。
     * 同guid
     */
    @XmlElement(name="MessageID")
    private String messageID;

    /**
     * 报文类型
     */
    @XmlElement(name="MessageType")
    private String messageType;

    /**
     * 企业组织机构代码或统一社会信用代码
     */
    @XmlElement(name="OrgCode")
    private String orgCode;

    /**
     * 传输企业代码
     * 报文传输的企业海关注册代码（需要与接入客户端的企业身份一致）
     */
    @XmlElement(name="CopCode")
    private String copCode;

    /**
     * 传输企业名称
     * 报文传输的企业海关注册名称
     */
    @XmlElement(name="CopName")
    private String copName;

    /**
     * 发送方
     * 企业客户端ID号
     */
    @XmlElement(name="SenderID")
    private String senderID;

    /**
     * 接收方
     * EPORT
     */
    @XmlElement(name="ReceiverID")
    private String receiverID;

    /**
     * 接收部门
     * 填写本报文发送的监管单位，可同时填写多个监管部门：
     *     C-海关；Q-检验检疫；
     *     例如：同时发送至海关、检验检疫可填写：CQ
     *     本节点根据监管部门要求将来可扩展
     */
    @XmlElement(name="ReceiverDepartment")
    private String receiverDepartment;

    /**
     * 发送时间
     * 格式：yyyyMMddHHmmssSSS
     */
    @XmlElement(name="SendTime")
    private String sendTime;

    /**
     * 版本号
     */
    @XmlElement(name="Version")
    private String version;

    @Override
    public String toString() {
        return "{" +
                "messageID='" + messageID + '\'' +
                ", messageType='" + messageType + '\'' +
                ", orgCode='" + orgCode + '\'' +
                ", copCode='" + copCode + '\'' +
                ", copName='" + copName + '\'' +
                ", senderID='" + senderID + '\'' +
                ", receiverID='" + receiverID + '\'' +
                ", receiverDepartment='" + receiverDepartment + '\'' +
                ", sendTime='" + sendTime + '\'' +
                ", version='" + version + '\'' +
                '}';
    }

    public String getMessageID() {
        return messageID;
    }

    public void setMessageID(String messageID) {
        this.messageID = messageID;
    }

    public String getMessageType() {
        return messageType;
    }

    public void setMessageType(String messageType) {
        this.messageType = messageType;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getCopCode() {
        return copCode;
    }

    public void setCopCode(String copCode) {
        this.copCode = copCode;
    }

    public String getCopName() {
        return copName;
    }

    public void setCopName(String copName) {
        this.copName = copName;
    }

    public String getSenderID() {
        return senderID;
    }

    public void setSenderID(String senderID) {
        this.senderID = senderID;
    }

    public String getReceiverID() {
        return receiverID;
    }

    public void setReceiverID(String receiverID) {
        this.receiverID = receiverID;
    }

    public String getReceiverDepartment() {
        return receiverDepartment;
    }

    public void setReceiverDepartment(String receiverDepartment) {
        this.receiverDepartment = receiverDepartment;
    }

    public String getSendTime() {
        return sendTime;
    }

    public void setSendTime(String sendTime) {
        this.sendTime = sendTime;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

}
