package com.emato.ccnet.cus.message.req.ceb411;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;

/**
 * 海关支付单 表头
 * Java报文对象转XML
 *
 * 表头(1:1)
 *
 * @author Scott Chen
 * @version 1.0
 * 2017-11-06 23:51
 */
@XmlAccessorType(XmlAccessType.FIELD)
public class Ceb411PaymentHead implements Serializable {

    private static final long serialVersionUID = 3304376487303900138L;

    /**
     * 报文唯一编号
     * 企业系统生成36位报文唯一序号（要求为guid36位，英文字母大写）。
     */
    @XmlElement
    private String guid;
    /**
     * 报送类型 C1
     * 报送类型：1-新增，2-修改，默认为1
     */
    @XmlElement
    private String appType;
    /**
     * 报送时间
     * 企业报送时间。格式:YYYYMMDDhhmmss。
     */
    @XmlElement
    private String appTime;
    /**
     * 业务状态
     * 业务状态:1-暂存,2-申报,默认为2。
     */
    @XmlElement
    private String appStatus;


    /**
     * 支付企业的海关注册登记编号
     */
    @XmlElement
    private String payCode;

    /**
     * 支付企业在海关注册登记的名称
     */
    @XmlElement
    private String payName;

    /**
     * 支付企业唯一的支付流水号
     */
    @XmlElement
    private String payTransactionId;

    /**
     * 交易平台的订单编号，同一交易平台的订单编号应唯一
     */
    @XmlElement
    private String orderNo;


    /**
     * 电商平台的海关注册登记编号；电商平台未在海关注册登记，由电商企业发送订单的，以中国电子口岸发布的电商平台标识编号为准
     */
    @XmlElement
    private String ebpCode;

    /**
     * 电商平台的海关注册登记名称；电商平台未在海关注册登记，由电商企业发送订单的，以中国电子口岸发布的电商平台名称为准
     */
    @XmlElement
    private String ebpName;

    /**
     * 1-身份证,2-其它。限定为身份证，填写“1”
     */
    @XmlElement
    private String payerIdType;

    /**
     * 支付人的身份证件号码
     */
    @XmlElement
    private String payerIdNumber;


    /**
     * 支付人的真实姓名
     */
    @XmlElement
    private String payerName;

    /**
     * 支付人的电话号码
     */
    @XmlElement
    private String telephone;

    /**
     * 支付金额
     */
    @XmlElement
    private String amountPaid;

    /**
     * 限定为人民币，填写“142”
     */
    @XmlElement
    private String currency;


    /**
     * 支付时间，格式:YYYYMMDDhhmmss
     */
    @XmlElement
    private String payTime;

    /**
     * 备注
     */
    @XmlElement
    private String note;

    @Override
    public String toString() {
        return "{" +
                "guid='" + guid + '\'' +
                ", appType='" + appType + '\'' +
                ", appTime='" + appTime + '\'' +
                ", appStatus='" + appStatus + '\'' +
                ", payCode='" + payCode + '\'' +
                ", payName='" + payName + '\'' +
                ", payTransactionId='" + payTransactionId + '\'' +
                ", orderNo='" + orderNo + '\'' +
                ", ebpCode='" + ebpCode + '\'' +
                ", ebpName='" + ebpName + '\'' +
                ", payerIdType='" + payerIdType + '\'' +
                ", payerIdNumber='" + payerIdNumber + '\'' +
                ", payerName='" + payerName + '\'' +
                ", telephone='" + telephone + '\'' +
                ", amountPaid='" + amountPaid + '\'' +
                ", currency='" + currency + '\'' +
                ", payTime='" + payTime + '\'' +
                ", note='" + note + '\'' +
                '}';
    }

    public String getGuid() {
        return guid;
    }

    public void setGuid(String guid) {
        this.guid = guid;
    }

    public String getAppType() {
        return appType;
    }

    public void setAppType(String appType) {
        this.appType = appType;
    }

    public String getAppTime() {
        return appTime;
    }

    public void setAppTime(String appTime) {
        this.appTime = appTime;
    }

    public String getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(String appStatus) {
        this.appStatus = appStatus;
    }

    public String getPayCode() {
        return payCode;
    }

    public void setPayCode(String payCode) {
        this.payCode = payCode;
    }

    public String getPayName() {
        return payName;
    }

    public void setPayName(String payName) {
        this.payName = payName;
    }

    public String getPayTransactionId() {
        return payTransactionId;
    }

    public void setPayTransactionId(String payTransactionId) {
        this.payTransactionId = payTransactionId;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getEbpCode() {
        return ebpCode;
    }

    public void setEbpCode(String ebpCode) {
        this.ebpCode = ebpCode;
    }

    public String getEbpName() {
        return ebpName;
    }

    public void setEbpName(String ebpName) {
        this.ebpName = ebpName;
    }

    public String getPayerIdType() {
        return payerIdType;
    }

    public void setPayerIdType(String payerIdType) {
        this.payerIdType = payerIdType;
    }

    public String getPayerIdNumber() {
        return payerIdNumber;
    }

    public void setPayerIdNumber(String payerIdNumber) {
        this.payerIdNumber = payerIdNumber;
    }

    public String getPayerName() {
        return payerName;
    }

    public void setPayerName(String payerName) {
        this.payerName = payerName;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getAmountPaid() {
        return amountPaid;
    }

    public void setAmountPaid(String amountPaid) {
        this.amountPaid = amountPaid;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public String getPayTime() {
        return payTime;
    }

    public void setPayTime(String payTime) {
        this.payTime = payTime;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }
}
