package com.emato.ccnet.cus.message.support;

import com.emato.ccnet.util.DataUtils;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * @author Scott Chen
 * @version 1.0
 * 2017-11-07 13:51
 */
public class CebSupport {
    /**
     * 请求报文文件名模板
     */
    public static final String CEB_NAME_TEMPLATE = "CEB_$messageType_$senderId_$receiverID_$time$random.xml";

    /**
     * 请求报文属性xmlns
     */
    public static final String xmlns = "http://www.chinaport.gov.cn/ceb";
    /**
     * 请求报文属性xmlns:xsi
     */
    public static final String xmlnsXsi = "http://www.w3.org/2001/XMLSchema-instance";
    /**
     * 请求报文属性version
     */
    public static final String version = "1.0";

    /**
     * 消息头接收方ID
     */
    public static final String RECEIVER_ID = "EPORT";

    /**
     * 表头 业务状态 新增
     */
    public static final String APP_TYPE_ADD = "1";

    /**
     * 表头 申报状态 申报
     */
    public static final String APP_status_decl = "2";

    /**
     * 证件类型 1:身份证
     */
    public static final String CEB_ID_TYPE = "1";

    /**
     * EPort请求-物流运单报文接收机构
     * C-海关；Q-检验检疫
     */
    public static final String ceb_cq = "CQ";

    public static final String ceb_c = "C";

    public static final String ceb_q = "CQ";

    /**
     * 电子订单-请求
     */
    public static final String CEB311 = "CEB311";

    /**
     * 支付单-请求
     */
    public static final String CEB411 = "CEB411";

    /**
     * 物流运单-请求
     */
    public static final String CEB511 = "CEB511";
    /**
     * #物流运单状态-请求
     */
    public static final String CEB513 = "CEB513";
    /**
     * 进口清单-请求
     */
    public static final String CEB621 = "CEB621";
    /**
     * 入库明细单-请求
     */
    public static final String CEB711 = "CEB711";

    /**
     * 构建EPort请求报文文件名
     *
     * @param messageType
     * @return
     */
    public static String buildFileName(String messageType, String senderId, String receiverID) {
        String time = DateTimeFormatter.ofPattern("yyyyMMddHHmmssSSS").format(LocalDateTime.now());
        int random = DataUtils.createRandomNumber(1000, 9999);
        String fileNameTemplate = CEB_NAME_TEMPLATE;
        return fileNameTemplate.replace("$messageType", messageType).replace("$senderId", senderId)
                .replace("$receiverID",receiverID)
                .replace("$time", time).replace("$random", Integer.valueOf(random).toString());
    }

}
