package com.emato.ccnet.service.ccent.impl;

import com.emato.ccnet.contants.Contants;
import com.emato.ccnet.config.Merchant;
import com.emato.ccnet.config.Cus;
import com.emato.ccnet.domain.kmall.PayBill;
import com.emato.ccnet.domain.ccnet.CusAlipay;
import com.emato.ccnet.domain.ccnet.CusAlipayStatus;
import com.emato.ccnet.domain.ccnet.CusPaymentCollect;
import com.emato.ccnet.mapper.ccnet.CusAlipayMapper;
import com.emato.ccnet.mapper.ccnet.CusAlipayStatusMapper;
import com.emato.ccnet.mapper.ccnet.CusPaymentCollectMapper;
import com.emato.ccnet.service.ccent.CusPaymentCollectService;
import com.emato.ccnet.snow.SnowflakeUtil;
import com.emato.ccnet.util.DateUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 海关支付单总表
 */
@Service
public class CusPaymentCollectImpl implements CusPaymentCollectService{

    private static final Logger logger = LoggerFactory.getLogger(CusPaymentCollectImpl.class);

    @Autowired
    private CusPaymentCollectMapper cusPaymentCollectMapper;

    @Autowired
    private Merchant merchant;

    @Autowired
    private CusAlipayMapper cusAlipayMapper;

    @Autowired
    private CusAlipayStatusMapper cusAlipayStatusMapper;

    @Autowired
    private Cus cus;
    /**
     * 生成报关流水号
     * @return
     */
    public static String getNormalOrderNo() {
        String orderNo = DateUtil.dateToString(new Date(),"yyyyMMddHHmmssSSSSS");

        return orderNo;
    }

    /**
     * 支付订单表相关的初始化
     * @param list
     * @return
     */
    @Override
    public int addCusPaymentCollect(List list) {
        //支付总表集合
        List<CusPaymentCollect> CusPaymentCollects = new ArrayList<>();
        //支付单阿里云集合
        List<CusAlipay> cusAlipays = new ArrayList<>();
        //支付单状态表集合
        List<CusAlipayStatus> cusAlipayStatuses = new ArrayList<>();

        //支付单数据
        List<PayBill> payBillList = (List<PayBill>) list;
        for (PayBill payBill : payBillList) {
            //支付总表
            String cusPaySn = Contants.ZWSH + SnowflakeUtil.getSnowNextId();
            String orderSn = Contants.ZW +SnowflakeUtil.getSnowNextId();
            CusPaymentCollect cusPaymentCollect = buildCusPaymentCollect(payBill,cusPaySn,orderSn);
            CusPaymentCollects.add(cusPaymentCollect);

            //支付表
            CusAlipay cusAlipay = buildCusAlipay(payBill,cusPaySn,orderSn);
            cusAlipays.add(cusAlipay);

            //支付表状态
            CusAlipayStatus cusAlipayStatus = buildCusAlipayStatus(payBill,cusPaySn,orderSn);
            cusAlipayStatuses.add(cusAlipayStatus);

        }

        if (cusPaymentCollectMapper.insertCusPaymentCollectItemBatch(CusPaymentCollects) <= 0) {
            logger.error("批量插入，支付总表记录全部失败");
            return 0;
        }

        if(cusAlipayMapper.insertCusAlipayItemBatch(cusAlipays) <= 0){
            logger.error("批量插入，支付单阿里云记录全部失败");
            return 0;
        }

        if(cusAlipayStatusMapper.insertCusAlipayStatusItemBatch(cusAlipayStatuses) <= 0){
            logger.error("批量插入，支付单状态记录全部失败");
            return 0;
        }

        return 1;
    }

    /**
     * 组装CusAlipayStatus
     * @param payBill
     * @param cusPaySn
     * @param orderSn
     * @return
     */
    private CusAlipayStatus buildCusAlipayStatus(PayBill payBill, String cusPaySn, String orderSn) {
        CusAlipayStatus cusAlipayStatus = new CusAlipayStatus();
        String cusAlipayStatusSn = Contants.ZWSH +SnowflakeUtil.getSnowNextId();
        cusAlipayStatus.setCusAlipayStatusSn(cusAlipayStatusSn);
        cusAlipayStatus.setCusPaySn(cusPaySn);
        cusAlipayStatus.setOrderSn(orderSn);
        cusAlipayStatus.setMerchOrderSn(payBill.getOrderNo());
        cusAlipayStatus.setMerchSn(merchant.getMerchSn());
        cusAlipayStatus.setMerchName(merchant.getMerchName());
        cusAlipayStatus.setPlatSn(merchant.getPlatSn());
        cusAlipayStatus.setPlatName(merchant.getPlatName());
        cusAlipayStatus.setThirdPartyMerchCode(payBill.getSellerId());
        cusAlipayStatus.setThirdPartyMerchName(payBill.getSellerName());
        cusAlipayStatus.setSendStatus(Contants.INIT_STATUS);
        cusAlipayStatus.setTradeNo(payBill.getTradeNo());
        cusAlipayStatus.setAlipayRespStatus(Contants.INIT_STATUS);
        cusAlipayStatus.setCreaterSn(Contants.CREATER_NUMBER);
        return cusAlipayStatus;
    }

    /**
     * 组装CusAlipay
     * @param payBill
     * @param cusPaySn
     * @param orderSn
     * @return
     */
    private CusAlipay buildCusAlipay(PayBill payBill, String cusPaySn, String orderSn) {
        CusAlipay cusAlipay = new CusAlipay();
        String cusAlipaySn = Contants.ZWSH +SnowflakeUtil.getSnowNextId();
        cusAlipay.setCusAlipaySn(cusAlipaySn);
        cusAlipay.setCusPaySn(cusPaySn);
        cusAlipay.setOrderSn(orderSn);
        cusAlipay.setMerchOrderSn(payBill.getOrderNo());
        cusAlipay.setMerchSn(merchant.getMerchSn());
        cusAlipay.setMerchName(merchant.getMerchName());
        cusAlipay.setPlatSn(merchant.getPlatSn());
        cusAlipay.setPlatName(merchant.getPlatName());
        cusAlipay.setThirdPartyMerchCode(payBill.getSellerId());
        cusAlipay.setThirdPartyMerchName(payBill.getSellerName());
        cusAlipay.setPlaceOrderlTime(payBill.getCreateTime());
        cusAlipay.setOutRequestNo(getNormalOrderNo());
        cusAlipay.setTradeNo(payBill.getTradeNo());
        cusAlipay.setMerchantCustomsCode(merchant.getMerchantCustomsCode());
        cusAlipay.setMerchantCustomsName(merchant.getMerchantCustomsName());
        cusAlipay.setAmount(payBill.getRealAmount());
        cusAlipay.setCustomsPlace(cus.getAlipay().get("customs-place"));
        cusAlipay.setIsSplit("");
        cusAlipay.setBuyerName(payBill.getTrueName());
        cusAlipay.setBuyerIdNo(payBill.getIdCode());
        cusAlipay.setCreaterSn(Contants.CREATER_NUMBER);
        cusAlipay.setCreateTime(new Date());
        return cusAlipay;
    }

    /**
     * 组装CusPaymentCollect
     * @param payBill
     * @param cusPaySn
     * @param orderSn
     * @return
     */
    private CusPaymentCollect buildCusPaymentCollect(PayBill payBill, String cusPaySn, String orderSn) {
        CusPaymentCollect cusPaymentCollect = new CusPaymentCollect();
        cusPaymentCollect.setOrderSn(orderSn);
        cusPaymentCollect.setCusPaySn(cusPaySn);
        cusPaymentCollect.setMerchOrderSn(payBill.getOrderNo());
        cusPaymentCollect.setMerchSn(merchant.getMerchSn());
        cusPaymentCollect.setThirdPartyMerchCode(payBill.getSellerId());
        cusPaymentCollect.setPayTransactionId(payBill.getTradeNo());
        cusPaymentCollect.setPayCompanyFlag(Contants.ALIPAY);
        cusPaymentCollect.setCreaterSn(Contants.INIT_STATUS);
        cusPaymentCollect.setCreateTime(new Date());
        return cusPaymentCollect;
    }
}
