package com.emato.ccnet.util;

import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import net.sf.json.xml.XMLSerializer;
import org.apache.commons.lang3.StringUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLFilterImpl;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import javax.xml.parsers.SAXParserFactory;
import javax.xml.transform.Source;
import javax.xml.transform.sax.SAXSource;
import java.io.File;
import java.io.StringReader;
import java.io.StringWriter;
import java.util.*;

/**
 * XML处理类
 *
 * @author Scott Chen
 * @date 2016/11/15
 */
public class XmlUtil {

    public static String toXML(Object obj, boolean format) throws Exception {
        try {
            JAXBContext context = JAXBContext.newInstance(obj.getClass());
            Marshaller marshaller = context.createMarshaller();

            //编码格式
            marshaller.setProperty(Marshaller.JAXB_ENCODING, "UTF-8");

            // 是否格式化生成的xml串
            if (format) {
                marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            }else{
                marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.FALSE);
            }

            // 是否省略xm头声明信息
            marshaller.setProperty(Marshaller.JAXB_FRAGMENT, Boolean.FALSE);

            StringWriter writer = new StringWriter();
            marshaller.marshal(obj, writer);
            return writer.toString();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public static String toXMLInFile(Object obj, String filePath, boolean format) throws Exception {
        try {
            JAXBContext context = JAXBContext.newInstance(obj.getClass());
            Marshaller marshaller = context.createMarshaller();

            //编码格式
            marshaller.setProperty(Marshaller.JAXB_ENCODING, "UTF-8");

            // 是否格式化生成的xml串
            if (format) {
                marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            }else{
                marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.FALSE);
            }

            // 是否省略xm头声明信息
            marshaller.setProperty(Marshaller.JAXB_FRAGMENT, Boolean.FALSE);

            File file = new File(filePath);
            marshaller.marshal(obj, file);

            StringWriter writer = new StringWriter();
            marshaller.marshal(obj, writer);
            return writer.toString();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    @SuppressWarnings("unchecked")
    public static <T> T fromXML(String xmlStr, Class<T> valueType, boolean ignoreNs) throws Exception {
        try {
            JAXBContext context = JAXBContext.newInstance(valueType);
            Unmarshaller unmarshaller = context.createUnmarshaller();
            StringReader reader = new StringReader(xmlStr);

            //解析时,是否忽略命名空间
            if (ignoreNs) {
                /**
                 * 忽略命名空间
                 * 在序列化和反序列化时通过XMLFilterImpl的匿名实现类实现命名空间及xml节点名称的控制
                 */
                SAXParserFactory sax = SAXParserFactory.newInstance();
                //false:忽略命名空间
                sax.setNamespaceAware(false);
                XMLReader xmlReader = sax.newSAXParser().getXMLReader();

                XMLFilterImpl nsfFilter = new XMLFilterImpl() {
                    private boolean ignoreNamespace = false;

                    @Override
                    public void startDocument() throws SAXException {
                        super.startDocument();
                    }

                    @Override
                    public void startElement(String uri, String localName, String qName, Attributes atts) throws SAXException {
                        if (this.ignoreNamespace){
                            uri = "";
                        }

                        super.startElement(uri, localName, qName, atts);
                    }

                    @Override
                    public void endElement(String uri, String localName, String qName) throws SAXException {
                        if (this.ignoreNamespace){
                            uri = "";
                        }

                        super.endElement(uri, localName, localName);
                    }

                    @Override
                    public void startPrefixMapping(String prefix, String url) throws SAXException {
                        if (!this.ignoreNamespace){
                            super.startPrefixMapping("", url);
                        }
                    }
                };
                nsfFilter.setParent(xmlReader);

                Source source = new SAXSource(xmlReader, new InputSource(reader));
                return (T) unmarshaller.unmarshal(source);
            }
            return (T) unmarshaller.unmarshal(reader);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * xml转map
     * @param xmlstr
     * @return
     */
    public static Map<String, Object> xmltoMap(String xmlstr){
        Document doc = null;
        try {
            doc = DocumentHelper.parseText(xmlstr);
        } catch (DocumentException e) {
            e.printStackTrace();
        }
        Element rootElement = doc.getRootElement();
        Map<String,Object> mapXml = new HashMap<String,Object>();
        elementToMap(mapXml,rootElement);
        return mapXml;
    }
    
    /**
     * 遍历子节点
     * @param mapXml
     * @param rootElement
     */
    private static void elementToMap(Map<String, Object> mapXml, Element rootElement) {
        //获得当前节点的子节点  
        List<Element> elements = rootElement.elements();
        Map<String,Object> childMap = new HashMap<String,Object>();
        //如果还存在子节点，就考虑list情况，继续递归 
        for (Element element : elements) {
            List<Element> es = element.elements();
            if(es.size()>0){
                //获取当前节点下的子节点
                ArrayList<Map> list = new ArrayList<Map>();
                for(Element e:es){
                    elementChildToList(list,e);
                }
                mapXml.put(element.getName(), list);
            }else{
                mapXml.put(element.getName(),element.getText());
            }

        }
    }
    /**
     * 递归子节点
     * @param arrayList
     * @param rootElement
     */
    private static void elementChildToList(ArrayList<Map> arrayList, Element rootElement) {
        //获得当前节点的子节点
        List<Element> elements = rootElement.elements();
        if(elements.size()>0){
            ArrayList<Map> list = new ArrayList<Map>();
            Map<String,Object> sameTempMap = new HashMap<String,Object>();
            for(Element element:elements){
                elementChildToList(list,element);
                sameTempMap.put(element.getName(), element.getText());
            }
            System.out.println(elements.size());
            arrayList.add(sameTempMap);
        }

    }

    public static Map<String,String> xmlToMap(String xml){
        JSONObject jsonObjects = convertXMLToJSON(xml);
        Map<String,String> map = new HashMap<>();
        Iterator iterators = jsonObjects.keys();
        while(iterators.hasNext()){
            String keys = (String) iterators.next();
            String values = jsonObjects.getString(keys);
            if(keys.equals("request")){
                JSONArray jsonArray =  JSONArray.fromObject(values);
                if(jsonArray.size()>0){
                    for(int i=0;i<jsonArray.size();i++){
                        JSONObject job = jsonArray.getJSONObject(i);  // 遍历 jsonarray 数组，把每一个对象转成 json 对象
                        // 得到 每个对象中的属性值
                        String key1 = String.valueOf(job.get("@name"));
                        String value1 = String.valueOf(job.get("#text"));
                        map.put(key1,value1);
                    }
                }

            }else if(keys.equals("response")){
                values = values.replace("[","").replace("]","");
                JSONObject jsonObject = JSONObject.fromObject(values);
                Iterator iterator = jsonObject.keys();
                while(iterator.hasNext()){
                    String key = (String) iterator.next();
                    String value = jsonObject.getString(key);
                    map.put(key,value);
                }
            }else{
                map.put(keys,values);
            }
        }
        return map;
    }

    /**

     * 将xml转换成JSON

     *

     * @param xml xml文件

     * @return

     * @author FanWeiJie

     * @date 2015年11月18日

     */
    private static JSONObject convertXMLToJSON(String xml) {
        if (StringUtils.isBlank(xml)) {
            return null;
        }
        // 防止xml头部尾部含有非法字符，造成无法转换

        if (xml.indexOf("<") != -1 && xml.lastIndexOf(">") != -1 && xml.lastIndexOf(">") > xml.indexOf("<")) {
            xml = xml.substring(xml.indexOf("<"), xml.lastIndexOf(">") + 1);
        }
        XMLSerializer xmlSerializer = new XMLSerializer();
        xmlSerializer.clearNamespaces();
        xmlSerializer.setTypeHintsEnabled(false);
        return JSONObject.fromObject(xmlSerializer.read(xml).toString());
    }

    public static void main(String[] args) {
        String str = "<?xml version=\"1.0\" encoding=\"utf-8\"?>" +
                "<alipay>" +
                "    <is_success>T</is_success>" +
                "    <request>" +
                "        <param name=\"sign\">eb9ece9d658e7a9671411d1b43b5750c</param>" +
                "        <param name=\"_input_charset\">UTF-8</param>" +
                "        <param name=\"sign_type\">MD5</param>" +
                "        <param name=\"service\">alipay.overseas.acquire.customs.query</param>" +
                "        <param name=\"out_request_nos\">4877067126133624,7665166179649532</param>" +
                "        <param name=\"partner\">2088101143686350</param>" +
                "    </request>" +
                "    <response>" +
                "        <alipay>" +
                "            <records>" +
                "                <customs_declare>" +
                "                    <alipay_declare_no>2015082011082370647505271</alipay_declare_no>" +
                "                    <amount>1.00</amount>" +
                "                    <is_split>T</is_split>" +
                "                    <sub_out_biz_no>999999999999999</sub_out_biz_no>" +
                "                    <customs_place>hangzhou</customs_place>" +
                "                    <last_modified_time>2015-10-15 14:24:56</last_modified_time>" +
                "                    <memo/>" +
                "                    <merchant_customs_code>code</merchant_customs_code>" +
                "                    <merchant_customs_name>1</merchant_customs_name>" +
                "                    <out_request_no>4877067126133624</out_request_no>" +
                "                    <status>succ</status>" +
                "                    <trade_no>2015082011082370647505271</trade_no>" +
                "                    <customs_code>2</customs_code>" +
                "                    <customs_info>新增申报成功[B0B2F23E-2CF6-434D-9F24-8931B835A056]</customs_info>" +
                "                    <customs_return_time>20160414142358</customs_return_time>" +
                "                </customs_declare>" +
                "                <customs_declare>" +
                "                    <alipay_declare_no>2015081811082379147506255</alipay_declare_no>" +
                "                    <amount>1.00</amount>" +
                "                    <customs_place>henan</customs_place>" +
                "                    <last_modified_time>2015-10-15 14:24:56</last_modified_time>" +
                "                    <memo/>" +
                "                    <merchant_customs_code>code</merchant_customs_code>" +
                "                    <merchant_customs_name>name</merchant_customs_name>" +
                "                    <out_request_no>7665166179649532</out_request_no>" +
                "                    <status>succ</status>" +
                "                    <trade_no>2015081710650237</trade_no>" +
                "                    <customs_code>2</customs_code>" +
                "                    <customs_info>新增申报成功[B0B2F23E-2CF6-434D-9F24-8931B835A056]</customs_info>" +
                "                    <customs_return_time>20160414142358</customs_return_time>" +
                "                </customs_declare>" +
                "            </records>" +
                "            <result_code>SUCCESS</result_code>" +
                "        </alipay>" +
                "    </response>" +
                "    <sign>15669c65f3d19d0691425bba349a8b55</sign>" +
                "    <sign_type>MD5</sign_type>" +
                "</alipay>";
        System.out.println(xmlToMap(str));
    }

}
